@@ -163,6 +163,12 @@ class BertSTEMForTextClassification:
                                                         return_attention_mask = True,   # Construct attn. masks.
                                                         return_tensors = 'pt')
 
+
+        device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
+
+        self._model.to(device)
+        encoded_text.to(device)
+
         with torch.no_grad():
             logits = self._model(encoded_text['input_ids'])['logits']
         
